@@ -640,7 +640,7 @@ class CAT(object):
         return fp, fn, tp, p, r, f1, cui_counts, examples
 
 
-    def get_entities(self, text, only_cui=False, addl_info=['cui2icd10', 'cui2ontologies']):
+    def get_entities(self, text, only_cui=False, addl_info=['cui2icd10', 'cui2ontologies', 'cui2snomed']):
         r''' Get entities
 
         text:  text to be annotated
@@ -683,7 +683,7 @@ class CAT(object):
                     out_ent['start'] = ent.start_char
                     out_ent['end'] = ent.end_char
                     for addl in addl_info:
-                        tmp = self.cdb.addl_info[addl].get(cui, [])
+                        tmp = self.cdb.addl_info.get(addl, {}).get(cui, [])
                         out_ent[addl.split("2")[-1]] = list(tmp) if type(tmp) == set else tmp
                     out_ent['id'] = ent._.id
                     out_ent['meta_anns'] = {}
